[−][src]Crate serpent
Serpent
This crate is an implementation of the Serpent cipher most known for being one of the leading candidates for AES.
It's based on the unoptimized C reference implementation and uses some of the test vectors given in their submission package to validate the implementation.
For easy interoperation with Rust crypto this crate implements
the BlockCipher trait from the block-cipher-trait crate.
Re-exports
pub use block_cipher_trait; |
pub use block_cipher_trait::generic_array; |
pub use generic_array::typenum; |
Structs
| Serpent | The Serpent cipher instance |